## Macaque_MotorCortex_LFP_Spike_VisuoMotorBehavior_Kilavik

The complete dataset that was used in [Confais et al. 2020](https://doi.org/10.1093/texcom/tgaa017) to study the relationship between LFP beta oscillation amplitude and firing rate of individual neurons in macaque motor cortex. The data is from two adult male macaques, and include LFPs and single neurons. 

Several preceding studies used partially overlapping data (Confais et al. 2012; Kilavik et al. 2010, 2012, 2014; Ponce-Alvarez et al. 2010). The only criteria of data exclusion in each of these studies were related to rejections of artefacts, in either local field potential (LFP) or spiking data.

The data from each monkey has been prepared in a .mat file, in 'structure' format, where the data of each pair of neuron-LFP has been cut in trials (including only correct trials), after rejection of trials with artefacts. We furthermore include continuous hand movement trajectories for the same trials.

The dataset contains 314 (monkey T) and 661 (monkey M) sorted single units, but less LFPs, since often the same LFP was paired with several units of the same session. The LFP and unit in a 'pair' was systematically taken from two separate electrodes. 



#### Dataset Origin
The dataset was collected in the lab of Dr. Alexa Riehle, Institut de Neurosciences Cognitives de la Méditerranée, Centre National de la Recherche Scientifique, Université Aix-Marseille II, Marseille, France. 

Data collection and preprocessing was done by Joachim Confais, Bjørg Kilavik, Adrian Ponce-Alvarez and Alexa Riehle. 



#### Ethics Statement
Two adult male Rhesus monkeys (T and M, both 9kg) participated in this study. Care and treatment of the animals during all stages of the experiments conformed to the European and French Government Regulations applicable at the time the experiments were performed (86/609/EEC).



#### Dataset Description

The behavioral setup and task are briefly described in the file **Setup&Task.pdf**. Further details on the task, animal preparation, recordings and data preprocssing can be found in the original research publication ([Confais et al. 2020](https://doi.org/10.1093/texcom/tgaa017)).

##### Fields of data structures:
There are as many rows in the structure as there were included neurons. The fields in the structure for each animal is as follows:
* session_ID
* Cell_ID - e.g. SpN1-1  for offline sorted (N) neuron on channel 1, unit 1; Spi3-2 for online sorted (i) neuron on channel 3, unit 2.
* LFP_ID - channel of LFP signal
* Twodir - NaN for regular session with all 12 conditions (6 directions in short and long delay trials), else the two directions used for sessions with only 4 conditions (2 opposite directions).
* TriggerSignal - always GO (207; at 4501ms; in column 6 in Fields TrialtimesCorr and TrialCodesCorr)
* TriggerCode - 207 (GO)
* TempResolu - '1 kHz'
* AP_ML_spi - position within recording chamber of channel providing neuron (see paper for details)
* AP_ML_lfp - position within recording chamber of channel providing LFP (see paper for details)
* Traject - hand movement trajectory informations (see more details below)
* lfp - LFP signal in each trial (with timing of GO at 4501ms), separated for the 12 (4) conditions
* spi - sparse matrix with 0/1, 1 marking action potential events (with timing of GO at 4501ms)
* TrialCodesCorr - task/behavioral codes (see more details below)
* TrialTimesCorr - timestamps of task/behavioral codes (even for codes for which the exact timing is irrelevant)
* TrialChronolOrderCorr - original trial number, including aborted/error trials (see more details below)

##### Traject - hand trajectory information 
* MvtOnset - movement onset estimated offline from hand trajectories, in ms with respect to GO
* TraX/Y - single trial hand trajectories starting between Start and TC and ending after reach completion
* sh_leftTime - the trigger event occurs at the time of column sh_leftTime+1 in TraX/Y in short trials
* lo_leftTime - the trigger event occurs at the time of column lo_leftTime+1 in TraX/Y in long trials
* rightTime - duration of trajectory follwing the trigger event in all trials
* TriggerSignal - GO
* TriggerCode - 207

##### TrialCodesCorr - temporal order of codes in all correct trials are:
* Trial condition: (1:12 or 1:4), coded at time of Start (CenterTouch)
* Timed task events: Start (1-12 according to trial condition), TCon (202), TCoff (203), SCon (204), DistrOn (206), GO (207) 
* Timed behavioral events: LeaveCenter (214) but use instead movement onset calculated from trajectories that is more accurate, EnterTarget (215)
* Trial codes: TargetDir (101:106) for directions 1-6, turning clockwise starting with direction 1 in the upper right quadrant; CorrectCode (121) indicating that the trial was performed correctly 
* Timed task event: Reward (201)
* Trial codes: CycleNum (51: ...); BlockNum(71: ...); TrialType (91 - short delays or 92 - long delays) 
* Timed task event: AllStimOff (209)

##### TrialChronolOrderCorr: how to sort data into chronological order of trials
* Trials are not organized in chronological order inside the structures.
* TrialChronolOrderCorr contains the original IDs of the trials. Sort these arrays, separately for each movement direction to get chronological order of correct trials. All trials were included in this counter (also those that were never initated, aborted or terminated with an error).

##### Additional information:
* Note that one LFP could be paired with several neurons within a session. Take care of session_ID and LFP_ID to use each LFP only once, for any analyses focusing on LFPs.
* Note that each neuron-LFP pair had their own set of trials with artefact that were excluded. Thus, in order to combine LFPs and/or neurons from the same session for analysis, take care that you only include trials with the same ID (based on TrialChronolOrderCorr).
* Note that for the complete dataset from Monkey T, and for parts of the dataset in Monkey M, the individual electrodes were organized in a bundle, with one common chamber coordinate for all electrodes. However, neuron-LFP pairs were always made by combining signals taken from different electrodes, to avoid spurious correlations. 



#### References for peer-reviewed publications that used this dataset (*exactly* or partly):
* *Confais J, Malfait N, Brochier T, Riehle A, Kilavik BE. 2020. Is there an intrinsic relationship between LFP beta oscillation amplitude and firing rate of individual neurons in macaque motor cortex? Cerebral Cortex Communications 1 (1), tgaa017*
* Confais J, Kilavik BE, Ponce-Alvarez A, Riehle A. 2012. On the anticipatory precue activity in motor cortex. J Neurosci. 32:15359–15368.
* Kilavik BE, Confais J, Ponce-Alvarez A, Diesmann M, Riehle A. 2010. Evoked potentials in motor cortical LFPs reflect task timing and behavioral performance. J Neurophysiol. 104:2338–2351.
* Kilavik BE, Confais J, Riehle A. 2014. Signs of timing in motor cortex during movement preparation and cue anticipation. Adv Exp Med Biol 829:121–142.
* Kilavik BE, Ponce-Alvarez A, Trachel R, Confais J, Takerkart S, Riehle A. 2012. Context-related frequency modulations of macaque motor cortical LFP beta oscillations. Cereb Cortex. 22:2148–2259.
* Ponce-Alvarez A, Kilavik BE, Riehle A. 2010. Comparison of local measures of spike time irregularity and relating variability to firing rate in motor cortical neurons. J Comput Neurosci. 29:351–365.
